summaryrefslogtreecommitdiffstats
path: root/kmymoney2/reports/reportaccount.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/reports/reportaccount.cpp')
-rw-r--r--kmymoney2/reports/reportaccount.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/reports/reportaccount.cpp b/kmymoney2/reports/reportaccount.cpp
index 5f091e2..cdc8097 100644
--- a/kmymoney2/reports/reportaccount.cpp
+++ b/kmymoney2/reports/reportaccount.cpp
@@ -83,7 +83,7 @@ void ReportAccount::calculateAccountHierarchy( void )
#endif
while (!file->isStandardAccount(parentid))
{
// take on the identity of our tqparent
resultid = parentid;
// and try again
@@ -305,7 +305,7 @@ unsigned ReportAccount::hierarchyDepth( void ) const
return ( m_nameHierarchy.size() );
}
-ReportAccount ReportAccount::tqparent( void ) const
+ReportAccount ReportAccount::parent( void ) const
{
return ReportAccount( parentAccountId() );
}
@@ -320,7 +320,7 @@ ReportAccount ReportAccount::topParent( void ) const
while (!file->isStandardAccount(parentid))
{
// take on the identity of our tqparent
resultid = parentid;
// and try again
@@ -83,7 +83,7 @@ void ReportAccount::calculateAccountHierarchy( void )
while (!file->isStandardAccount(parentid))
{
- // take on the identity of our tqparent
+ // take on the identity of our parent
resultid = parentid;
// and try again
@@ -320,7 +320,7 @@ ReportAccount ReportAccount::topParent( void ) const
while (!file->isStandardAccount(parentid))
{
- // take on the identity of our tqparent
+ // take on the identity of our parent
resultid = parentid;
// and try again